# pip install ERLC

import asyncio
import sys

sys.path.append('../')
from ERLC.erlc import ErlcClient


async def main():
    erlc_client = ErlcClient()

    server_key = 'your_server_key'
    global_key = 'your_global_key'

    await erlc_client.config(server_key, global_key)

    if erlc_client.connected:
        print("Connected to ERLC!")
    else:
        print("Failed to connect to ERLC.")
    

asyncio.run(main())


# pip install ERLC

import asyncio
from ERLC.erlc import ErlcClient

async def main():
    erlc_client = ErlcClient()

    server_key = 'your_server_key'
    global_key = 'your_global_key'

    await erlc_client.config(server_key, global_key)

    if erlc_client.connected:
        print("Connected to ERLC!")
    else:
        print("Failed to connect to ERLC.")
        
    bans = await erlc_client.server.players()
    print(bans)

asyncio.run(main())


import asyncio
import logging
from .server import ServerClient as Server
import httpx

class ErlcClient:
    def __init__(self):
        self.connected = False
        self.global_key = None
        self.server_key = None
        self.server = None 
        self.client = None

    async def config(self, server_key: str, global_key: str):
        if self.connected:
            return logging.error("You are already connected to ERLC.")

        if global_key is None:
            logging.info("You have not submitted a global API key.")

        self.server_key = server_key
        self.global_key = global_key

        self.client = await self.fetch_async_client()

        self.server = Server(async_client=self.client)

        self.connected = True
        logging.info("Your API keys are now ready to be used.")

    async def disconnect(self):
        if not self.connected:
            return logging.error("You are not connected to ERLC.")

        await asyncio.sleep(1)
        logging.info("Your API keys have been removed.")

        self.connected = False
        self.server_key = None
        self.global_key = None
        self.server = None
        self.client = None

    async def reconnect(self):
        logging.info("Reconnecting to ERLC...")
        await self.disconnect()
        await self.connect(self.server_key, self.global_key)
    
    
    async def fetch_async_client(self):
        return AsyncClient(server_key=self.server_key, global_key=self.global_key)

class AsyncClient:
    def __init__(self, server_key, global_key):
        self.server_key = server_key
        self.global_key = global_key


client = ErlcClient()



import httpx
import asyncio
import logging

async def request(endpoint, method="GET", headers=None, params=None, data=None):
    base_api_url = "api.policeroleplay.community/v1"
    full_url = f"{base_api_url}/{endpoint}"

    async with httpx.AsyncClient() as client:
        try:
            response = await client.request(method, full_url, headers=headers, params=params, data=data)

            if 200 <= response.status_code < 300:
                logging.info(f"Request to {full_url} successful. Status code: {response.status_code}")
            else:
                logging.error(f"Request to {full_url} failed. Status code: {response.status_code}")

        except httpx.RequestError as e:
            logging.error(f"Request to {full_url} failed. Error: {e}")
            return None

        return response


import httpx
import asyncio
import logging
from  .Server.getPlayers import players
from .Server.getStatus import status
from .Server.getBans import bans
from .Server.getJoins import joinlogs
from .Server.getQueue import Queue
from .Server.runCmd import run_command
from .Server.getKills import killlogs
from .Server.getCmds import commands



class ServerClient:
    def __init__(self, async_client):
        self.async_client = async_client
        
    async def players(self):
        """Fetches the ERLC server Players
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await players(self=self, async_client=self.async_client)
    
    async def status(self):
        """Fetches the ERLC server Status
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await status(self=self, async_client=self.async_client)
        
    async def bans(self):
        """Fetches the ERLC server Ban Logs
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await bans(self=self, async_client=self.async_client)
        
    async def joinlogs(self):
        """Fetches the ERLC server Join Logs
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await joinlogs(self=self, async_client=self.async_client)
    
    async def killlogs(self):
        """Fetches the ERLC server Kill Logs
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await killlogs(self=self, async_client=self.async_client)
    
    async def queue(self):
        """Fetches the ERLC server Queue
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await Queue(self=self, async_client=self.async_client)
        
    async def run_command(self, command: str):
        """Runs a command in the ERLC server
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await run_command(self=self, async_client=self.async_client, command=command)
    
    async def commandlogs(self):
        """Fetches the ERLC server Command Logs
                
        Parameters:
            None
                
        Returns:
            Tuple (status_code, data)
            """
        status_code, data = await commands(self=self, async_client=self.async_client)
        
        


        


        


        




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ERLC",                 
    version="1.2.4",                     
    author="mark.api",                    
    description="An API wrapper for the ERLC API",
    long_description=long_description,      
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),  
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],                                     
    python_requires='>=3.6',               
    install_requires=[]                  
)